import { Queue } from './queue';
/**
 * An implementation of the {@link Queue} interface using an array
 */
export declare class ArrayQueue<T> implements Queue<T> {
    /**
     * The array containing every element.
     */
    protected array: T[];
    /**
     * Instantiate the queue.
     *
     * @param elements - A set of elements to initialize the queue with.
     */
    constructor(elements?: Iterable<T>);
    clear(): void;
    dequeue(): T | undefined;
    enqueue(element: T): number;
    peek(): T | undefined;
    get size(): number;
    /**
     * Receive an iterator through the queue.
     *
     * **Note:** Unexpected behavior can occur if the collection is modified during iteration.
     *
     * @returns An iterator through the queue
     */
    [Symbol.iterator](): Iterator<T>;
}
